<!--![apppath](.github/images/apppath.svg)-->

<p align="center">
  <img src=".github/images/apppath.svg" alt='AppPath' />
</p>

<h1 align="center">AppPath</h1>

<!--# AppPath-->

[![Build Status](https://travis-ci.com/pything/apppath.svg?branch=master)](https://travis-ci.com/pything/apppath) | [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black) | [![Coverage Status](https://coveralls.io/repos/github/pything/apppath/badge.svg?branch=master)](https://coveralls.io/github/pything/apppath?branch=master) | [![Total alerts](https://img.shields.io/lgtm/alerts/g/pything/apppath.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/pything/apppath/alerts/) | [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/pything/apppath.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/pything/apppath/context:python)
|---|---|---|---|---|

| Workflows |
|-----------|
| ![Publish Python 🐍 distributions 📦 to PyPI and TestPyPI](https://github.com/pything/apppath/workflows/Publish%20Python%20%F0%9F%90%8D%20distributions%20%F0%9F%93%A6%20to%20PyPI%20and%20TestPyPI/badge.svg) |
| ![On Push Any Documentation Check](https://github.com/pything/apppath/workflows/On%20Push%20Any%20Documentation%20Check/badge.svg) |
|  ![CodeQL](https://github.com/pything/apppath/workflows/CodeQL/badge.svg) |

___
> Clutter-free app data

![python](.github/images/python.svg)
___

A class and a set of functions for providing for system-consensual path for apps to store data, logs, cache...
